"""Study on domain with multiple fragments.

The original idea is to study domains with multiple fragments, and
their G' results. Manually is observed that such domains can have thread
spanning multiple fragments, resulting in a wrong G' calculation.

This scripts aims to study the statistics of the event.
"""
import csv
import json
import pathlib
import sys

sys.path.append("/home/ubuntu/membrane/")
from stats_dataset.utils import domain_segments_parser

parent = pathlib.Path(__file__).parent.resolve()
membrane_dir = pathlib.Path("/mnt/MEMBRANE")
ge_dir = pathlib.Path("/mnt/GE_lx")

# -------------- Load fragment domains -------------- #
domains_file = membrane_dir / "chains_list.csv"
with open(domains_file, "r") as in_file:
    reader = csv.reader(in_file, delimiter=",")
    fragment_domains = {}
    for row in reader:
        doms = domain_segments_parser(
            json.loads(row[4].replace("'", "\""))
        )
        for d, ra in doms.items():
            if len(ra) > 1:
                fragment_domains[d.upper()] = ra

print(f"Number of fragment domains: {len(fragment_domains)}")

# -------------- create list of such domains -------------- #
out_file = parent / "fragmented_domains.csv"
with open(out_file, "w") as out_file:
    writer = csv.writer(out_file, delimiter=",")
    writer.writerow(["# Generated by domain_fragment.py"])
    writer.writerow(["# domain", "cath_fragments"])
    for d, ra in fragment_domains.items():
        writer.writerow([d, ra])

# -------------- Load G' data -------------- #
input_dir = ge_dir / "DOMAINS" / "LOOPS"
file_list = [
    f for f in input_dir.iterdir() if f.suffix == ".csv" and f.stem in fragment_domains
]
# NOTE: the two number might not be the same because the calculation has to finish
print(f"Number of fragment domains with G' data: {len(file_list)}")
