"""Generate two files: trans and mono with gmaxc and gmaxn data."""
import argparse
import csv
import pathlib


parent = pathlib.Path(__file__).parent.resolve()

# -------------- Parse arguments -------------- #
parser = argparse.ArgumentParser()
parser.add_argument(
    "region",
    help="Choose between 'domains' and 'chains'.",
    choices=["domains", "chains"],
)
args = parser.parse_args()

# -------------- Load data -------------- #
parent = pathlib.Path(__file__).parent.resolve()
input_file = parent / "ge_list_files" / f"ge_c_n_{args.region}.csv"

# parse trans-mono info
trans_mono_dir = (
    parent / ".." /
    "stats_dataset/classification/transmembrane_monotopic_list.csv"
)
with open(trans_mono_dir, "r") as in_file:
    reader = csv.reader(in_file, delimiter=",")
    transmono = {}
    next(reader)
    for row in reader:
        if not row[0] in transmono:
            transmono[row[0].replace("_", "").upper()] = row[1]

# parse int-peri info
int_peri_dir = (
    parent / ".." /
    "stats_dataset/classification/intrinsic_peripheral_list.csv"
)
with open(int_peri_dir, "r") as in_file:
    reader = csv.reader(in_file, delimiter=",")
    intperi = {}
    next(reader)
    for row in reader:
        if not row[0] in intperi:
            intperi[row[0].replace("_", "").upper()] = row[1]

# TRANS/MONO
trans_out_file = open(parent / "ge_list_files" / "trans_g_n_c.csv", "w")
mono_out_file = open(parent / "ge_list_files" / "mono_g_n_c.csv", "w")
other_out_file = open(parent / "ge_list_files" / "other_g_n_c.csv", "w")
writer_trans = csv.writer(trans_out_file)
writer_mono = csv.writer(mono_out_file)
writer_other = csv.writer(other_out_file)
writer_trans.writerow(["# domain", "gmaxn", "gmaxc"])
writer_mono.writerow(["# domain", "gmaxn", "gmaxc"])
writer_other.writerow(["# domain", "gmaxn", "gmaxc"])

# INT/PERI
int_out_file = open(parent / "ge_list_files" / "int_g_n_c.csv", "w")
peri_out_file = open(parent / "ge_list_files" / "peri_g_n_c.csv", "w")
other2_out_file = open(parent / "ge_list_files" / "other2_g_n_c.csv", "w")
writer_int = csv.writer(int_out_file)
writer_peri = csv.writer(peri_out_file)
writer_other2 = csv.writer(other2_out_file)
writer_int.writerow(["# domain", "gmaxn", "gmaxc"])
writer_peri.writerow(["# domain", "gmaxn", "gmaxc"])
writer_other2.writerow(["# domain", "gmaxn", "gmaxc"])


with open(input_file, "r") as in_file:
    reader = csv.reader(in_file, delimiter=",")
    for row in reader:
        if row[0].startswith("#"):
            continue

        if row[5] != "None" and row[10] != "None":
            if row[0][:5] in transmono:
                if transmono[row[0][:5]] == "trans":
                    writer_trans.writerow([row[0], row[5], row[10]])
                elif transmono[row[0][:5]] == "mono":
                    writer_mono.writerow([row[0], row[5], row[10]])
                elif transmono[row[0][:5]] == "other":
                    writer_other.writerow([row[0], row[5], row[10]])
                else:
                    raise ValueError(f"Unknown classification: {transmono[row[0][:5]]}")
        
            if row[0][:5] in intperi:
                if intperi[row[0][:5]] == "intr":
                    writer_int.writerow([row[0], row[5], row[10]])
                elif intperi[row[0][:5]] == "peri":
                    writer_peri.writerow([row[0], row[5], row[10]])
                elif intperi[row[0][:5]] == "other":
                    writer_other2.writerow([row[0], row[5], row[10]])
                else:
                    raise ValueError(f"Unknown classification: {intperi[row[0][:5]]}")

trans_out_file.close()
mono_out_file.close()
other_out_file.close()

int_out_file.close()
peri_out_file.close()
other2_out_file.close()
